/****************************************************************************
** Meta object code from reading C++ file 'UIMediumManager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/VBox/Frontends/VirtualBox/src/medium/UIMediumManager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UIMediumManager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24UIEnumerationProgressBarE_t {};
} // unnamed namespace

template <> constexpr inline auto UIEnumerationProgressBar::qt_create_metaobjectdata<qt_meta_tag_ZN24UIEnumerationProgressBarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UIEnumerationProgressBar"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UIEnumerationProgressBar, qt_meta_tag_ZN24UIEnumerationProgressBarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UIEnumerationProgressBar::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24UIEnumerationProgressBarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24UIEnumerationProgressBarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24UIEnumerationProgressBarE_t>.metaTypes,
    nullptr
} };

void UIEnumerationProgressBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UIEnumerationProgressBar *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *UIEnumerationProgressBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UIEnumerationProgressBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24UIEnumerationProgressBarE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int UIEnumerationProgressBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN21UIMediumManagerWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto UIMediumManagerWidget::qt_create_metaobjectdata<qt_meta_tag_ZN21UIMediumManagerWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UIMediumManagerWidget",
        "sigCreateMedium",
        "",
        "sigCopyMedium",
        "QUuid",
        "uMediumId",
        "sigMediumDetailsVisibilityChanged",
        "fVisible",
        "sigAcceptAllowed",
        "fAllowed",
        "sigRejectAllowed",
        "sltResetMediumDetailsChanges",
        "sltApplyMediumDetailsChanges",
        "sltHandleMediumCreated",
        "uMediumID",
        "sltHandleMediumDeleted",
        "sltHandleMediumEnumerationStart",
        "sltHandleMediumEnumerated",
        "sltHandleMediumEnumerationFinish",
        "sltHandleMachineStateChange",
        "uId",
        "KMachineState",
        "state",
        "sltAddMedium",
        "sltCreateMedium",
        "sltCopyMedium",
        "sltMoveMedium",
        "sltRemoveMedium",
        "sltReleaseMedium",
        "sltClear",
        "sltToggleMediumDetailsVisibility",
        "sltToggleMediumSearchVisibility",
        "sltRefreshAll",
        "sltEditVISO",
        "sltHandleMoveProgressFinished",
        "sltHandleResizeProgressFinished",
        "sltHandleCurrentTabChanged",
        "sltHandleCurrentItemChanged",
        "sltHandleContextMenuRequest",
        "QPoint",
        "position",
        "sltPerformTablesAdjustment",
        "sltHandlePerformSearch",
        "sltDetachCOM",
        "sltRetranslateUI"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigCreateMedium'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigCopyMedium'
        QtMocHelpers::SignalData<void(const QUuid &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'sigMediumDetailsVisibilityChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'sigAcceptAllowed'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'sigRejectAllowed'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'sltResetMediumDetailsChanges'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sltApplyMediumDetailsChanges'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sltHandleMediumCreated'
        QtMocHelpers::SlotData<void(const QUuid &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 14 },
        }}),
        // Slot 'sltHandleMediumDeleted'
        QtMocHelpers::SlotData<void(const QUuid &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 14 },
        }}),
        // Slot 'sltHandleMediumEnumerationStart'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltHandleMediumEnumerated'
        QtMocHelpers::SlotData<void(const QUuid &)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 14 },
        }}),
        // Slot 'sltHandleMediumEnumerationFinish'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltHandleMachineStateChange'
        QtMocHelpers::SlotData<void(const QUuid &, const KMachineState)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 20 }, { 0x80000000 | 21, 22 },
        }}),
        // Slot 'sltAddMedium'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltCreateMedium'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltCopyMedium'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltMoveMedium'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltRemoveMedium'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltReleaseMedium'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltClear'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltToggleMediumDetailsVisibility'
        QtMocHelpers::SlotData<void(bool)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'sltToggleMediumSearchVisibility'
        QtMocHelpers::SlotData<void(bool)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'sltRefreshAll'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltEditVISO'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltHandleMoveProgressFinished'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltHandleResizeProgressFinished'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltHandleCurrentTabChanged'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltHandleCurrentItemChanged'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltHandleContextMenuRequest'
        QtMocHelpers::SlotData<void(const QPoint &)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 39, 40 },
        }}),
        // Slot 'sltPerformTablesAdjustment'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltHandlePerformSearch'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltDetachCOM'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltRetranslateUI'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UIMediumManagerWidget, qt_meta_tag_ZN21UIMediumManagerWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UIMediumManagerWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21UIMediumManagerWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21UIMediumManagerWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21UIMediumManagerWidgetE_t>.metaTypes,
    nullptr
} };

void UIMediumManagerWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UIMediumManagerWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigCreateMedium(); break;
        case 1: _t->sigCopyMedium((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
        case 2: _t->sigMediumDetailsVisibilityChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->sigAcceptAllowed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->sigRejectAllowed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->sltResetMediumDetailsChanges(); break;
        case 6: _t->sltApplyMediumDetailsChanges(); break;
        case 7: _t->sltHandleMediumCreated((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
        case 8: _t->sltHandleMediumDeleted((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
        case 9: _t->sltHandleMediumEnumerationStart(); break;
        case 10: _t->sltHandleMediumEnumerated((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
        case 11: _t->sltHandleMediumEnumerationFinish(); break;
        case 12: _t->sltHandleMachineStateChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KMachineState>>(_a[2]))); break;
        case 13: _t->sltAddMedium(); break;
        case 14: _t->sltCreateMedium(); break;
        case 15: _t->sltCopyMedium(); break;
        case 16: _t->sltMoveMedium(); break;
        case 17: _t->sltRemoveMedium(); break;
        case 18: _t->sltReleaseMedium(); break;
        case 19: _t->sltClear(); break;
        case 20: _t->sltToggleMediumDetailsVisibility((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->sltToggleMediumSearchVisibility((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->sltRefreshAll(); break;
        case 23: _t->sltEditVISO(); break;
        case 24: _t->sltHandleMoveProgressFinished(); break;
        case 25: _t->sltHandleResizeProgressFinished(); break;
        case 26: _t->sltHandleCurrentTabChanged(); break;
        case 27: _t->sltHandleCurrentItemChanged(); break;
        case 28: _t->sltHandleContextMenuRequest((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 29: _t->sltPerformTablesAdjustment(); break;
        case 30: _t->sltHandlePerformSearch(); break;
        case 31: _t->sltDetachCOM(); break;
        case 32: _t->sltRetranslateUI(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KMachineState >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UIMediumManagerWidget::*)()>(_a, &UIMediumManagerWidget::sigCreateMedium, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMediumManagerWidget::*)(const QUuid & )>(_a, &UIMediumManagerWidget::sigCopyMedium, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMediumManagerWidget::*)(bool )>(_a, &UIMediumManagerWidget::sigMediumDetailsVisibilityChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMediumManagerWidget::*)(bool )>(_a, &UIMediumManagerWidget::sigAcceptAllowed, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMediumManagerWidget::*)(bool )>(_a, &UIMediumManagerWidget::sigRejectAllowed, 4))
            return;
    }
}

const QMetaObject *UIMediumManagerWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UIMediumManagerWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21UIMediumManagerWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int UIMediumManagerWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    return _id;
}

// SIGNAL 0
void UIMediumManagerWidget::sigCreateMedium()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void UIMediumManagerWidget::sigCopyMedium(const QUuid & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void UIMediumManagerWidget::sigMediumDetailsVisibilityChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void UIMediumManagerWidget::sigAcceptAllowed(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void UIMediumManagerWidget::sigRejectAllowed(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN15UIMediumManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto UIMediumManager::qt_create_metaobjectdata<qt_meta_tag_ZN15UIMediumManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UIMediumManager",
        "sigDataChangeRejected",
        "",
        "sigDataChangeAccepted",
        "sltHandleButtonBoxClick",
        "QAbstractButton*",
        "pButton",
        "sltRetranslateUI"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigDataChangeRejected'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigDataChangeAccepted'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sltHandleButtonBoxClick'
        QtMocHelpers::SlotData<void(QAbstractButton *)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'sltRetranslateUI'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UIMediumManager, qt_meta_tag_ZN15UIMediumManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UIMediumManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QIManagerDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15UIMediumManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15UIMediumManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15UIMediumManagerE_t>.metaTypes,
    nullptr
} };

void UIMediumManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UIMediumManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigDataChangeRejected(); break;
        case 1: _t->sigDataChangeAccepted(); break;
        case 2: _t->sltHandleButtonBoxClick((*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[1]))); break;
        case 3: _t->sltRetranslateUI(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UIMediumManager::*)()>(_a, &UIMediumManager::sigDataChangeRejected, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMediumManager::*)()>(_a, &UIMediumManager::sigDataChangeAccepted, 1))
            return;
    }
}

const QMetaObject *UIMediumManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UIMediumManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15UIMediumManagerE_t>.strings))
        return static_cast<void*>(this);
    return QIManagerDialog::qt_metacast(_clname);
}

int UIMediumManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QIManagerDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void UIMediumManager::sigDataChangeRejected()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void UIMediumManager::sigDataChangeAccepted()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
